@@ -93,10 +93,14 @@ class CacheConfig(BaseModel):
     @field_validator('redis_url')
     @classmethod
     def validate_redis_url(cls, v: Optional[str]) -> Optional[str]:
-        """Validate Redis URL format."""
+        """Validate Redis URL format. Allows environment variable templates like ${VAR:-default}."""
         if v is None:
             return v
 
+        # Skip validation for environment variable templates
+        if v.startswith("${") and "}" in v:
+            return v
+
         if not v.startswith(('redis://', 'rediss://')):
             raise ValueError(
                 "Redis URL must start with 'redis://' or 'rediss://' "
