@@ -11,13 +11,10 @@ MODULES_REGISTRY = {
     "set_current_config": ("django_cfg.core.config", "set_current_config"),
 
     # Centrifugo module
-    "DjangoCfgCentrifugoConfig": ("django_cfg.apps.centrifugo.services.client.config", "DjangoCfgCentrifugoConfig"),
+    "DjangoCfgCentrifugoConfig": ("django_cfg.apps.integrations.centrifugo.services.client.config", "DjangoCfgCentrifugoConfig"),
 
-    # gRPC module
+    # gRPC module (uses flat API - no nested config imports needed)
     "GRPCConfig": ("django_cfg.models.api.grpc", "GRPCConfig"),
-    "GRPCServerConfig": ("django_cfg.models.api.grpc", "GRPCServerConfig"),
-    "GRPCAuthConfig": ("django_cfg.models.api.grpc", "GRPCAuthConfig"),
-    "GRPCProtoConfig": ("django_cfg.models.api.grpc", "GRPCProtoConfig"),
 
     # Next.js Admin Integration
     "NextJsAdminConfig": ("django_cfg.modules.nextjs_admin", "NextJsAdminConfig"),
